@@ -9,6 +9,7 @@ from kedro.framework.hooks import hook_impl
 from kedro.io import DataCatalog
 from kedro.pipeline import Pipeline
 from kedro.versioning.journal import _git_sha
+from mlflow.entities import RunStatus
 from mlflow.models import infer_signature
 
 from kedro_mlflow.framework.context import get_mlflow_config
@@ -75,7 +76,7 @@ class MlflowPipelineHook:
         )
 
         mlflow_conf = get_mlflow_config(self.context)
-        mlflow.set_tracking_uri(mlflow_conf.mlflow_tracking_uri)
+        mlflow_conf.setup(self.context)
 
         run_name = (
             mlflow_conf.run_opts["name"]
@@ -109,7 +110,10 @@ class MlflowPipelineHook:
 
     @hook_impl
     def after_pipeline_run(
-        self, run_params: Dict[str, Any], pipeline: Pipeline, catalog: DataCatalog,
+        self,
+        run_params: Dict[str, Any],
+        pipeline: Pipeline,
+        catalog: DataCatalog,
     ) -> None:
         """Hook to be invoked after a pipeline runs.
         Args:
@@ -191,7 +195,7 @@ class MlflowPipelineHook:
         """
 
         while mlflow.active_run():
-            mlflow.end_run()
+            mlflow.end_run(RunStatus.to_string(RunStatus.FAILED))
 
 
 mlflow_pipeline_hook = MlflowPipelineHook()
